summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/kernel
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/kernel')
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/qt_kernel.pri6
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqabstractlayout.cpp72
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqapplication.cpp2
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqapplication.cpp~2
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqlayout.cpp86
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqlayout.h32
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqlayoutengine.cpp8
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqlayoutengine_p.h6
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqobject.cpp4
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqrichtext.cpp6
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqrichtext_p.h4
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqsizegrip.cpp8
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqsizegrip.h2
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqstyle.h4
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqt.h4
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqtglobaldefines.h20
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp2
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp.new2
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqwidget.cpp50
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqwidget.h10
20 files changed, 165 insertions, 165 deletions
diff --git a/experimental/tqtinterface/qt4/src/kernel/qt_kernel.pri b/experimental/tqtinterface/qt4/src/kernel/qt_kernel.pri
index aa76de0e8..492b7b5c0 100644
--- a/experimental/tqtinterface/qt4/src/kernel/qt_kernel.pri
+++ b/experimental/tqtinterface/qt4/src/kernel/qt_kernel.pri
@@ -72,8 +72,8 @@ kernel {
$$KERNEL_H/tqsignalmapper.h \
$$KERNEL_H/tqsignalslotimp.h \
$$KERNEL_H/tqsize.h \
- $$KERNEL_H/tqsizegrip.h \
- $$KERNEL_H/tqsizepolicy.h \
+ $$KERNEL_H/sizegrip.h \
+ $$KERNEL_H/sizepolicy.h \
$$KERNEL_H/tqsocketnotifier.h \
$$KERNEL_H/tqsound.h \
$$KERNEL_H/tqstyle.h \
@@ -222,7 +222,7 @@ kernel {
$$KERNEL_CPP/tqsignal.cpp \
$$KERNEL_CPP/tqsignalmapper.cpp \
$$KERNEL_CPP/tqsize.cpp \
- $$KERNEL_CPP/tqsizegrip.cpp \
+ $$KERNEL_CPP/sizegrip.cpp \
$$KERNEL_CPP/tqstyle.cpp \
$$KERNEL_CPP/tqsocketnotifier.cpp \
$$KERNEL_CPP/tqsound.cpp \
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqapplication.cpp b/experimental/tqtinterface/qt4/src/kernel/tqapplication.cpp
index af193c986..b8c1c79a9 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqapplication.cpp
+++ b/experimental/tqtinterface/qt4/src/kernel/tqapplication.cpp
@@ -2480,7 +2480,7 @@ void TQApplication::setColorSpec( int spec )
Example:
\code
- TQSize& WidgetClass::tqsizeHint() const
+ TQSize& WidgetClass::sizeHint() const
{
return TQSize( 80, 25 ).expandedTo( TQApplication::globalStrut() );
}
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqapplication.cpp~ b/experimental/tqtinterface/qt4/src/kernel/tqapplication.cpp~
index ff6077613..9e2bdd2a6 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqapplication.cpp~
+++ b/experimental/tqtinterface/qt4/src/kernel/tqapplication.cpp~
@@ -2480,7 +2480,7 @@ void TQApplication::setColorSpec( int spec )
Example:
\code
- TQSize& WidgetClass::tqsizeHint() const
+ TQSize& WidgetClass::sizeHint() const
{
return TQSize( 80, 25 ).expandedTo( TQApplication::globalStrut() );
}
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqlayout.cpp b/experimental/tqtinterface/qt4/src/kernel/tqlayout.cpp
index e9f5493d1..a5c86dd79 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqlayout.cpp
+++ b/experimental/tqtinterface/qt4/src/kernel/tqlayout.cpp
@@ -46,7 +46,7 @@
#include "tqwidget.h"
#include "tqmenubar.h"
#include "tqptrlist.h"
-#include "tqsizepolicy.h"
+#include "sizepolicy.h"
#include "tqlayoutengine_p.h"
@@ -98,7 +98,7 @@ TQLayout *TQLayout::tqlayout() {
return this;
}
-TQSize TQLayout::tqsizeHint() const {
+TQSize TQLayout::sizeHint() const {
return sizeHint();
}
@@ -1451,7 +1451,7 @@ public:
{ item_ = TQT_TQLAYOUTITEM(new TQSpacerItem( w, h, hData, vData )); }
~TQGridBox() { delete item_; }
- QSize tqsizeHint() const { return item_->sizeHint(); }
+ QSize sizeHint() const { return item_->sizeHint(); }
QSize tqminimumSize() const { return item_->minimumSize(); }
QSize tqmaximumSize() const { return item_->maximumSize(); }
TQ_SPExpandData expandingDirections() const { return item_->expandingDirections(); }
@@ -1505,7 +1505,7 @@ public:
void add( TQGridBox*, int row, int col );
void add( TQGridBox*, int row1, int row2, int col1, int col2 );
- QSize tqsizeHint( int ) const;
+ QSize sizeHint( int ) const;
QSize tqminimumSize( int ) const;
QSize tqmaximumSize( int ) const;
@@ -1650,7 +1650,7 @@ void TQGridLayoutData::recalcHFW( int w, int spacing )
int mh = 0;
int n = 0;
for ( int r = 0; r < rr; r++ ) {
- h += rData[r].tqsizeHint;
+ h += rData[r].sizeHint;
mh += rData[r].tqminimumSize;
if ( !rData[r].empty )
n++;
@@ -1765,9 +1765,9 @@ TQ_SPExpandData TQGridLayoutData::expanding( int spacing )
return (TQ_SPExpandData) ret;
}
-QSize TQGridLayoutData::tqsizeHint( int spacer ) const
+QSize TQGridLayoutData::sizeHint( int spacer ) const
{
- return tqfindSize( &TQLayoutStruct::tqsizeHint, spacer );
+ return tqfindSize( &TQLayoutStruct::sizeHint, spacer );
}
QSize TQGridLayoutData::tqmaximumSize( int spacer ) const
@@ -1878,7 +1878,7 @@ void TQGridLayoutData::add( TQGridBox *box, int row1, int row2, int col1,
void TQGridLayoutData::addData( TQGridBox *box, bool r, bool c )
{
- TQSize hint = box->tqsizeHint();
+ TQSize hint = box->sizeHint();
TQSize minS = box->tqminimumSize();
TQSize maxS = box->tqmaximumSize();
@@ -1886,8 +1886,8 @@ void TQGridLayoutData::addData( TQGridBox *box, bool r, bool c )
if ( !cStretch[box->col] )
colData[box->col].stretch = TQMAX( colData[box->col].stretch,
box->hStretch() );
- colData[box->col].tqsizeHint = TQMAX( hint.width(),
- colData[box->col].tqsizeHint );
+ colData[box->col].sizeHint = TQMAX( hint.width(),
+ colData[box->col].sizeHint );
colData[box->col].tqminimumSize = TQMAX( minS.width(),
colData[box->col].tqminimumSize );
@@ -1899,8 +1899,8 @@ void TQGridLayoutData::addData( TQGridBox *box, bool r, bool c )
if ( !rStretch[box->row] )
rowData[box->row].stretch = TQMAX( rowData[box->row].stretch,
box->vStretch() );
- rowData[box->row].tqsizeHint = TQMAX( hint.height(),
- rowData[box->row].tqsizeHint );
+ rowData[box->row].sizeHint = TQMAX( hint.height(),
+ rowData[box->row].sizeHint );
rowData[box->row].tqminimumSize = TQMAX( minS.height(),
rowData[box->row].tqminimumSize );
@@ -1935,7 +1935,7 @@ void TQGridLayoutData::addData( TQGridBox *box, bool r, bool c )
static void distributeMultiBox( TQMemArray<TQLayoutStruct> &chain, int spacing,
int start, int end,
- int minSize, int tqsizeHint,
+ int minSize, int sizeHint,
TQMemArray<int> &stretchArray, int stretch )
{
int i;
@@ -1944,7 +1944,7 @@ static void distributeMultiBox( TQMemArray<TQLayoutStruct> &chain, int spacing,
int max = 0;
for ( i = start; i <= end; i++ ) {
w += chain[i].tqminimumSize;
- wh += chain[i].tqsizeHint;
+ wh += chain[i].sizeHint;
max += chain[i].tqmaximumSize;
chain[i].empty = FALSE;
if ( stretchArray[i] == 0 )
@@ -1983,11 +1983,11 @@ static void distributeMultiBox( TQMemArray<TQLayoutStruct> &chain, int spacing,
}
}
- if ( wh < tqsizeHint ) {
- qGeomCalc( chain, start, end - start + 1, 0, tqsizeHint, spacing );
+ if ( wh < sizeHint ) {
+ qGeomCalc( chain, start, end - start + 1, 0, sizeHint, spacing );
for ( i = start; i <= end; i++ ) {
- if ( chain[i].tqsizeHint < chain[i].size )
- chain[i].tqsizeHint = chain[i].size;
+ if ( chain[i].sizeHint < chain[i].size )
+ chain[i].sizeHint = chain[i].size;
}
}
}
@@ -2031,7 +2031,7 @@ void TQGridLayoutData::setupLayoutData( int spacing )
if ( c2 < 0 )
c2 = cc - 1;
- TQSize hint = box->tqsizeHint();
+ TQSize hint = box->sizeHint();
TQSize min = box->tqminimumSize();
if ( box->hasHeightForWidth() )
has_hfw = TRUE;
@@ -2065,13 +2065,13 @@ void TQGridLayoutData::addHfwData( TQGridBox *box, int width )
TQMemArray<TQLayoutStruct> &rData = *hfwData;
if ( box->hasHeightForWidth() ) {
int hint = box->heightForWidth( width );
- rData[box->row].tqsizeHint = TQMAX( hint, rData[box->row].tqsizeHint );
+ rData[box->row].sizeHint = TQMAX( hint, rData[box->row].sizeHint );
rData[box->row].tqminimumSize = TQMAX( hint, rData[box->row].tqminimumSize );
} else {
- TQSize hint = box->tqsizeHint();
+ TQSize hint = box->sizeHint();
TQSize minS = box->tqminimumSize();
- rData[box->row].tqsizeHint = TQMAX( hint.height(),
- rData[box->row].tqsizeHint );
+ rData[box->row].sizeHint = TQMAX( hint.height(),
+ rData[box->row].sizeHint );
rData[box->row].tqminimumSize = TQMAX( minS.height(),
rData[box->row].tqminimumSize );
}
@@ -2079,7 +2079,7 @@ void TQGridLayoutData::addHfwData( TQGridBox *box, int width )
/*
Similar to setupLayoutData(), but uses heightForWidth(colData)
- instead of tqsizeHint(). Assumes that setupLayoutData() and
+ instead of sizeHint(). Assumes that setupLayoutData() and
qGeomCalc(colData) has been called.
*/
void TQGridLayoutData::setupHfwLayoutData( int spacing )
@@ -2088,7 +2088,7 @@ void TQGridLayoutData::setupHfwLayoutData( int spacing )
int i;
for ( i = 0; i < rr; i++ ) {
rData[i] = rowData[i];
- rData[i].tqminimumSize = rData[i].tqsizeHint = 0;
+ rData[i].tqminimumSize = rData[i].sizeHint = 0;
}
TQPtrListIterator<TQGridBox> it( things );
TQGridBox * box;
@@ -2114,7 +2114,7 @@ void TQGridLayoutData::setupHfwLayoutData( int spacing )
if ( r1 == r2 ) {
addHfwData( box, w );
} else {
- TQSize hint = box->tqsizeHint();
+ TQSize hint = box->sizeHint();
TQSize min = box->tqminimumSize();
if ( box->hasHeightForWidth() ) {
int hfwh = box->heightForWidth( w );
@@ -2465,9 +2465,9 @@ int TQGridLayout::numCols() const
/*!
Returns the preferred size of this grid.
*/
-TQSize TQGridLayout::tqsizeHint() const
+TQSize TQGridLayout::sizeHint() const
{
- return data->tqsizeHint( spacing() ) + TQSize( 2 * margin(), 2 * margin() );
+ return data->sizeHint( spacing() ) + TQSize( 2 * margin(), 2 * margin() );
}
/*!
@@ -2641,7 +2641,7 @@ void TQGridLayout::addMultiCell( QLayoutItem *item, int fromRow, int toRow,
\i From TQt 3.0, the \a tqalignment parameter is interpreted more
aggressively than in previous versions of TQt. A non-default
tqalignment now indicates that the widget should not grow to fill
- the available space, but should be sized according to tqsizeHint().
+ the available space, but should be sized according to sizeHint().
\endlist
\sa addMultiCellWidget()
@@ -2673,7 +2673,7 @@ void TQGridLayout::addWidget( TQWidget *w, int row, int col, int tqalignment )
A non-zero tqalignment indicates that the widget should not grow to
fill the available space but should be sized according to
- tqsizeHint().
+ sizeHint().
\sa addWidget()
*/
@@ -2714,7 +2714,7 @@ void TQGridLayout::addLayout( TQLayout *tqlayout, int row, int col )
A non-zero tqalignment indicates that the tqlayout should not grow to
fill the available space but should be sized according to
- tqsizeHint().
+ sizeHint().
\a tqlayout becomes a child of the grid tqlayout.
@@ -2858,7 +2858,7 @@ int TQGridLayout::colSpacing( int col ) const
/*!
Returns whether this tqlayout can make use of more space than
- tqsizeHint(). A value of \c Vertical or \c Horizontal means that it wants
+ sizeHint(). A value of \c Vertical or \c Horizontal means that it wants
to grow in only one dimension, whereas \c BothDirections means that
it wants to grow in both dimensions.
*/
@@ -2998,7 +2998,7 @@ public:
int hfwWidth;
int hfwHeight;
int hfwMinHeight;
- TQSize tqsizeHint;
+ TQSize sizeHint;
TQSize minSize;
TQSize maxSize;
TQ_SPExpandData expanding;
@@ -3206,13 +3206,13 @@ TQBoxLayout::~TQBoxLayout()
/*!
Returns the preferred size of this box tqlayout.
*/
-TQSize TQBoxLayout::tqsizeHint() const
+TQSize TQBoxLayout::sizeHint() const
{
if ( data->dirty ) {
TQBoxLayout *that = (TQBoxLayout*)this;
that->setupGeom();
}
- return data->tqsizeHint + TQSize( 2 * margin(), 2 * margin() );
+ return data->sizeHint + TQSize( 2 * margin(), 2 * margin() );
}
/*!
@@ -3328,7 +3328,7 @@ TQLayoutItem* TQBoxLayout::takeAt(int index) {
/*!
Returns whether this tqlayout can make use of more space than
- tqsizeHint(). A value of \c Vertical or \c Horizontal means that it wants
+ sizeHint(). A value of \c Vertical or \c Horizontal means that it wants
to grow in only one dimension, whereas \c BothDirections means that
it wants to grow in both dimensions.
*/
@@ -3362,7 +3362,7 @@ void TQBoxLayout::setGeometry( const TQRect &r )
for ( int i = 0; i < n; i++ ) {
TQBoxLayoutItem *box = data->list.at( i );
if ( box->item->hasHeightForWidth() )
- a[i].tqsizeHint = a[i].tqminimumSize =
+ a[i].sizeHint = a[i].tqminimumSize =
box->item->heightForWidth( s.width() );
}
}
@@ -3528,7 +3528,7 @@ void TQBoxLayout::insertLayout( int index, TQLayout *tqlayout, int stretch )
From TQt 3.0, the \a tqalignment parameter is interpreted more
aggressively than in previous versions of TQt. A non-default
tqalignment now indicates that the widget should not grow to fill
- the available space, but should be sized according to tqsizeHint().
+ the available space, but should be sized according to sizeHint().
\sa setAutoAdd(), insertLayout(), insertSpacing()
*/
@@ -3592,7 +3592,7 @@ void TQBoxLayout::addStretch( int stretch )
From TQt 3.0, the \a tqalignment parameter is interpreted more
aggressively than in previous versions of TQt. A non-default
tqalignment now indicates that the widget should not grow to fill
- the available space, but should be sized according to tqsizeHint().
+ the available space, but should be sized according to sizeHint().
\sa insertWidget(), setAutoAdd(), addLayout(), addSpacing()
*/
@@ -3717,7 +3717,7 @@ void TQBoxLayout::setDirection( Direction direction )
if ( sp ) {
if ( sp->expandingDirections() == TQSizePolicy::NoDirection ) {
//spacing or strut
- TQSize s = sp->tqsizeHint();
+ TQSize s = sp->sizeHint();
sp->changeSize( s.height(), s.width(),
horz(direction) ? TQSizePolicy::Fixed:TQSizePolicy::Minimum,
horz(direction) ? TQSizePolicy::Minimum:TQSizePolicy::Fixed );
@@ -3795,7 +3795,7 @@ void TQBoxLayout::setupGeom()
minh = TQMAX( minh, min.height() );
hinth = TQMAX( hinth, hint.height() );
- a[i].tqsizeHint = hint.width();
+ a[i].sizeHint = hint.width();
a[i].tqmaximumSize = max.width();
a[i].tqminimumSize = min.width();
a[i].expansive = expand;
@@ -3812,7 +3812,7 @@ void TQBoxLayout::setupGeom()
minw = TQMAX( minw, min.width() );
hintw = TQMAX( hintw, hint.width() );
- a[i].tqsizeHint = hint.height();
+ a[i].sizeHint = hint.height();
a[i].tqmaximumSize = max.height();
a[i].tqminimumSize = min.height();
a[i].expansive = expand;
@@ -3831,7 +3831,7 @@ void TQBoxLayout::setupGeom()
( (horexp ? TQSizePolicy::Horizontally : 0)
| (verexp ? TQSizePolicy::Vertically : 0) );
- data->tqsizeHint = TQSize( hintw, hinth )
+ data->sizeHint = TQSize( hintw, hinth )
.expandedTo( data->minSize )
.boundedTo( data->maxSize );
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqlayout.h b/experimental/tqtinterface/qt4/src/kernel/tqlayout.h
index 5423cad5b..d96483815 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqlayout.h
+++ b/experimental/tqtinterface/qt4/src/kernel/tqlayout.h
@@ -52,7 +52,7 @@
#ifndef TQT_H
#include "tqobject.h"
-#include "tqsizepolicy.h"
+#include "sizepolicy.h"
#include "tqwidget.h"
#endif // TQT_H
@@ -170,7 +170,7 @@ public:
virtual inline void tqinvalidate() { QLayoutItem::invalidate(); }
virtual inline void invalidate() { tqinvalidate(); }
-// inline virtual TQSize tqsizeHint() const { return QLayoutItem::sizeHint(); }
+// inline virtual TQSize sizeHint() const { return QLayoutItem::sizeHint(); }
// inline virtual TQSize tqminimumSize() const { return QLayoutItem::minimumSize(); }
// inline virtual TQSize tqmaximumSize() const { return QLayoutItem::maximumSize(); }
// inline virtual void setGeometry( const TQRect&r ) { QLayoutItem::setGeometry(r); }
@@ -178,7 +178,7 @@ public:
// inline virtual TQ_SPExpandData expandingDirections() const { return QLayoutItem::expandingDirections(); }
// These functions are pure virtual in Qt4
- inline TQSize tqsizeHint() const { return sizeHint(); }
+ inline TQSize sizeHint() const { return sizeHint(); }
inline TQSize tqminimumSize() const { return minimumSize(); }
inline TQSize tqmaximumSize() const { return maximumSize(); }
// inline void setGeometry( const TQRect&r ) { TQ_UNUSED(r); }
@@ -189,7 +189,7 @@ public:
// This requires that the base virtual Qt functions be reimplemented so as to point to the TQt virtual functions instead as shown below.
// This way, when Trinity overrides a TQt virtual function, the calling Qt code will blithely use the overriden TQt function instead.
#define QLAYOUTITEM_REQUIRED_FUNCTIONS \
- virtual inline QSize sizeHint() const { return tqsizeHint(); } \
+ virtual inline QSize sizeHint() const { return sizeHint(); } \
virtual inline QSize minimumSize() const { return tqminimumSize(); } \
virtual inline QSize maximumSize() const { return tqmaximumSize(); } \
virtual inline void setGeometry( const QRect &r ) { return setGeometry( TQT_TQRECT_OBJECT(r) ); } \
@@ -211,7 +211,7 @@ public:
// virtual int heightForWidth( int ) const;
// virtual TQLayoutIterator iterator();
//
-// virtual TQSize tqsizeHint() const = 0;
+// virtual TQSize sizeHint() const = 0;
// virtual TQSize tqminimumSize() const = 0;
// virtual TQSize tqmaximumSize() const = 0;
// virtual void setGeometry( const TQRect& ) = 0;
@@ -223,7 +223,7 @@ public:
// // Use the TQt virtual functions, not the built in Qt ones...
// // This requires that the base virtual Qt functions be reimplemented so as to point to the TQt virtual functions instead as shown below.
// // This way, when Trinity overrides a TQt virtual function, the calling Qt code will blithely use the overriden TQt function instead.
-// inline QSize sizeHint() const { return tqsizeHint(); }
+// inline QSize sizeHint() const { return sizeHint(); }
// inline QSize minimumSize() const { return tqminimumSize(); }
// inline QSize maximumSize() const { return tqmaximumSize(); }
// inline void setGeometry( const QRect &r ) { return TQLayoutItem::setGeometry( r ); }
@@ -240,7 +240,7 @@ class TQ_EXPORT TQLayoutItem
public:
TQLayoutItem( int tqalignment = 0 ) : align( tqalignment ) { }
virtual ~TQLayoutItem();
- virtual TQSize tqsizeHint() const = 0;
+ virtual TQSize sizeHint() const = 0;
virtual TQSize tqminimumSize() const = 0;
virtual TQSize tqmaximumSize() const = 0;
virtual TQ_SPExpandData expandingDirections() const = 0;
@@ -278,7 +278,7 @@ public:
TQ_SPExpandData expandingDirections() const; // Used by tqabstractlayout.cpp
bool isEmpty() const; // Used by tqabstractlayout.cpp
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
TQSize tqminimumSize() const;
TQSize tqmaximumSize() const;
void setGeometry( const TQRect &qr );
@@ -287,7 +287,7 @@ public:
// Use the TQt virtual functions, not the built in Qt ones...
// This requires that the base virtual Qt functions be reimplemented so as to point to the TQt virtual functions instead as shown below.
// This way, when Trinity overrides a TQt virtual function, the calling Qt code will blithely use the overriden TQt function instead.
- inline QSize sizeHint() const { return tqsizeHint(); }
+ inline QSize sizeHint() const { return sizeHint(); }
inline QSize minimumSize() const { return tqminimumSize(); }
inline QSize maximumSize() const { return tqmaximumSize(); }
inline void setGeometry( const QRect &r ) { return TQSpacerItem::setGeometry( TQT_TQRECT_OBJECT(r) ); }
@@ -306,7 +306,7 @@ public:
void changeSize( int w, int h,
TQSizePolicy::SizeType hData = TQSizePolicy::Minimum,
TQSizePolicy::SizeType vData = TQSizePolicy::Minimum );
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
TQSize tqminimumSize() const;
TQSize tqmaximumSize() const;
TQ_SPExpandData expandingDirections() const;
@@ -328,7 +328,7 @@ class TQ_EXPORT TQWidgetItem : public TQLayoutItem
{
public:
TQWidgetItem( TQWidget *w ) : wid( w ) { }
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
TQSize tqminimumSize() const;
TQSize tqmaximumSize() const;
TQ_SPExpandData expandingDirections() const;
@@ -369,7 +369,7 @@ public:
virtual TQ_SPExpandData expandingDirections() const;
TQLayout *tqlayout();
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
virtual TQSize tqminimumSize() const;
virtual TQSize tqmaximumSize() const;
@@ -652,7 +652,7 @@ inline void TQLayoutIterator::deleteCurrent()
int count() const; \
TQLayoutItem* itemAt(int index) const; \
TQLayoutItem* takeAt(int index); \
- virtual inline QSize sizeHint() const { return tqsizeHint(); } \
+ virtual inline QSize sizeHint() const { return sizeHint(); } \
virtual inline QSize minimumSize() const { return tqminimumSize(); } \
virtual inline QSize maximumSize() const { return tqmaximumSize(); } \
virtual inline void setGeometry( const QRect &r ) { return setGeometry( TQT_TQRECT_OBJECT(r) ); } \
@@ -720,7 +720,7 @@ public:
delete hack;
}
- inline TQSize tqsizeHint() const { return sizeHint(); }
+ inline TQSize sizeHint() const { return sizeHint(); }
inline TQSize tqminimumSize() const { return minimumSize(); }
inline TQSize tqmaximumSize() const { return maximumSize(); }
inline void tqinvalidate() { invalidate(); }
@@ -956,7 +956,7 @@ public:
int spacing = -1, const char *name = 0 );
~TQGridLayout();
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
TQSize tqminimumSize() const;
TQSize tqmaximumSize() const;
@@ -1064,7 +1064,7 @@ public:
bool setStretchFactor( TQWidget*, int stretch );
bool setStretchFactor( TQLayout *l, int stretch );
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
TQSize tqminimumSize() const;
TQSize tqmaximumSize() const;
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqlayoutengine.cpp b/experimental/tqtinterface/qt4/src/kernel/tqlayoutengine.cpp
index 7dca5e0e6..8c364d9a3 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqlayoutengine.cpp
+++ b/experimental/tqtinterface/qt4/src/kernel/tqlayoutengine.cpp
@@ -256,7 +256,7 @@ TQ_EXPORT TQSize tqSmartMinSize( const TQWidgetItem *i )
if ( TQT_TQSIZEPOLICY_OBJECT(w->sizePolicy()).mayShrinkHorizontally() ) {
s.setWidth( w->tqminimumSizeHint().width() );
} else {
- sh = w->tqsizeHint();
+ sh = w->sizeHint();
s.setWidth( sh.width() );
}
}
@@ -266,7 +266,7 @@ TQ_EXPORT TQSize tqSmartMinSize( const TQWidgetItem *i )
s.setHeight( w->tqminimumSizeHint().height() );
} else {
s.setHeight( sh.isValid() ? sh.height()
- : w->tqsizeHint().height() );
+ : w->sizeHint().height() );
}
}
}
@@ -298,11 +298,11 @@ TQ_EXPORT TQSize tqSmartMaxSize( const TQWidgetItem *i, int align )
TQSize s = w->tqmaximumSize();
if ( s.width() == TQWIDGETSIZE_MAX && !(align & TQt::AlignHorizontal_Mask) )
if ( !TQT_TQSIZEPOLICY_OBJECT(w->sizePolicy()).mayGrowHorizontally() )
- s.setWidth( w->tqsizeHint().width() );
+ s.setWidth( w->sizeHint().width() );
if ( s.height() == TQWIDGETSIZE_MAX && !(align & TQt::AlignVertical_Mask) )
if ( !TQT_TQSIZEPOLICY_OBJECT(w->sizePolicy()).mayGrowVertically() )
- s.setHeight( w->tqsizeHint().height() );
+ s.setHeight( w->sizeHint().height() );
s = s.expandedTo( w->tqminimumSize() );
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqlayoutengine_p.h b/experimental/tqtinterface/qt4/src/kernel/tqlayoutengine_p.h
index 9c8064b21..bf6876e54 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqlayoutengine_p.h
+++ b/experimental/tqtinterface/qt4/src/kernel/tqlayoutengine_p.h
@@ -69,19 +69,19 @@ struct TQLayoutStruct
{
inline void init( int stretchFactor = 0, int spacing = 0 ) {
stretch = stretchFactor;
- tqminimumSize = tqsizeHint = spacing;
+ tqminimumSize = sizeHint = spacing;
tqmaximumSize = TQLAYOUTSIZE_MAX;
expansive = FALSE;
empty = TRUE;
}
TQCOORD smartSizeHint() {
- return ( stretch > 0 ) ? tqminimumSize : tqsizeHint;
+ return ( stretch > 0 ) ? tqminimumSize : sizeHint;
}
// parameters
int stretch;
- TQCOORD tqsizeHint;
+ TQCOORD sizeHint;
TQCOORD tqmaximumSize;
TQCOORD tqminimumSize;
bool expansive;
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqobject.cpp b/experimental/tqtinterface/qt4/src/kernel/tqobject.cpp
index 9bec0241f..5e87d6f7b 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqobject.cpp
+++ b/experimental/tqtinterface/qt4/src/kernel/tqobject.cpp
@@ -817,7 +817,7 @@ void TQObject::timerEvent( TQTimerEvent * )
TQApplication::sendPostedEvents( this, TQEvent::ChildInserted );
\endcode
in functions that depend on the state. One notable example is
- TQWidget::tqsizeHint().
+ TQWidget::sizeHint().
\sa event(), TQChildEvent
*/
@@ -1774,7 +1774,7 @@ void TQObject::timerEvent( TQTimerEvent * )
TQApplication::sendPostedEvents( this, TQEvent::ChildInserted );
\endcode
in functions that depend on the state. One notable example is
- TQWidget::tqsizeHint().
+ TQWidget::sizeHint().
\sa event(), TQChildEvent
*/
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqrichtext.cpp b/experimental/tqtinterface/qt4/src/kernel/tqrichtext.cpp
index 8b614d610..c518cc7b1 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqrichtext.cpp
+++ b/experimental/tqtinterface/qt4/src/kernel/tqrichtext.cpp
@@ -8232,7 +8232,7 @@ TQTextTableCell::~TQTextTableCell()
richtext = 0;
}
-TQSize TQTextTableCell::tqsizeHint() const
+TQSize TQTextTableCell::sizeHint() const
{
int extra = 2 * (parent->innerborder + parent->cellpadding + border_tolerance);
int used = richtext->widthUsed() + extra;
@@ -16164,7 +16164,7 @@ void TQTextTable::resize( int nwidth )
width = nwidth;
tqlayout->tqinvalidate();
- int shw = tqlayout->tqsizeHint().width() + 2*outerborder;
+ int shw = tqlayout->sizeHint().width() + 2*outerborder;
int mw = tqlayout->tqminimumSize().width() + 2*outerborder;
if ( stretch )
width = TQMAX( mw, nwidth );
@@ -16488,7 +16488,7 @@ TQTextTableCell::~TQTextTableCell()
richtext = 0;
}
-TQSize TQTextTableCell::tqsizeHint() const
+TQSize TQTextTableCell::sizeHint() const
{
int extra = 2 * ( tqparent->innerborder + tqparent->cellpadding + border_tolerance);
int used = richtext->widthUsed() + extra;
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqrichtext_p.h b/experimental/tqtinterface/qt4/src/kernel/tqrichtext_p.h
index b9cbd98a3..291d70869 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqrichtext_p.h
+++ b/experimental/tqtinterface/qt4/src/kernel/tqrichtext_p.h
@@ -615,7 +615,7 @@ public:
TQMimeSourceFactory &factory, TQStyleSheet *sheet, const TQString& doc);
virtual ~TQTextTableCell();
- TQSize tqsizeHint() const ;
+ TQSize sizeHint() const ;
TQSize tqminimumSize() const ;
TQSize tqmaximumSize() const ;
Qt::Orientations expandingDirections() const;
@@ -2788,7 +2788,7 @@ public:
TQMimeSourceFactory &factory, TQStyleSheet *sheet, const TQString& doc );
virtual ~TQTextTableCell();
- TQSize tqsizeHint() const ;
+ TQSize sizeHint() const ;
TQSize tqminimumSize() const ;
TQSize tqmaximumSize() const ;
TQ_SPExpandData expandingDirections() const;
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqsizegrip.cpp b/experimental/tqtinterface/qt4/src/kernel/tqsizegrip.cpp
index bcea2dbec..f47665133 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqsizegrip.cpp
+++ b/experimental/tqtinterface/qt4/src/kernel/tqsizegrip.cpp
@@ -38,7 +38,7 @@
**
**********************************************************************/
-#include "tqsizegrip.h"
+#include "sizegrip.h"
#ifndef TQT_NO_SIZEGRIP
@@ -79,7 +79,7 @@ static TQWidget* qt_sizegrip_workspace( TQWidget* w )
/*!
- \class TQSizeGrip tqsizegrip.h
+ \class TQSizeGrip sizegrip.h
\brief The TQSizeGrip class provides a corner-grip for resizing a top-level window.
@@ -153,9 +153,9 @@ TQSizeGrip::~TQSizeGrip()
/*!
Returns the size grip's size hint; this is a small size.
*/
-TQSize TQSizeGrip::tqsizeHint() const
+TQSize TQSizeGrip::sizeHint() const
{
- return (tqstyle().tqsizeFromContents(TQStyle::CT_SizeGrip, this, TQSize(13, 13)).
+ return (tqstyle().sizeFromContents(TQStyle::CT_SizeGrip, this, TQSize(13, 13)).
expandedTo(TQApplication::globalStrut()));
}
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqsizegrip.h b/experimental/tqtinterface/qt4/src/kernel/tqsizegrip.h
index fa893a286..2a01172ee 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqsizegrip.h
+++ b/experimental/tqtinterface/qt4/src/kernel/tqsizegrip.h
@@ -55,7 +55,7 @@ public:
TQSizeGrip( TQWidget* tqparent, const char* name=0 );
~TQSizeGrip();
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
protected:
void paintEvent( TQPaintEvent * );
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqstyle.h b/experimental/tqtinterface/qt4/src/kernel/tqstyle.h
index 5d657d854..ce58adb2d 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqstyle.h
+++ b/experimental/tqtinterface/qt4/src/kernel/tqstyle.h
@@ -256,7 +256,7 @@ inline TQStyleOption::TQStyleOption(const QStyleOption& qso) {
#define TQT_TQSTYLE_QT4_INTERFACE_VFUNC_01 inline void drawPrimitive(QStyle::PrimitiveElement pe, const QStyleOption *opt, QPainter *p, const QWidget *w) const { TQ_UNUSED(opt); TQ_UNUSED(w); static_cast<const TQStyle*>(this)->tqdrawPrimitive(pe, static_cast<TQPainter*>(p), TQRect(), TQColorGroup()); }
-#define TQT_TQSTYLE_QT4_INTERFACE_VFUNC_02 inline QSize sizeFromContents(ContentsType ct, const QStyleOption *opt, const QSize &contentsSize, const QWidget *w) const { return static_cast<const TQStyle*>(this)->tqsizeFromContents( ct, static_cast<const TQWidget*>(w), contentsSize, TQT_TQSTYLEOPTION_OBJECT(*opt) ); }
+#define TQT_TQSTYLE_QT4_INTERFACE_VFUNC_02 inline QSize sizeFromContents(ContentsType ct, const QStyleOption *opt, const QSize &contentsSize, const QWidget *w) const { return static_cast<const TQStyle*>(this)->sizeFromContents( ct, static_cast<const TQWidget*>(w), contentsSize, TQT_TQSTYLEOPTION_OBJECT(*opt) ); }
#define TQT_TQSTYLE_QT4_INTERFACE_VFUNC_03 inline QRect itemTextRect(const QFontMetrics &fm, const QRect &r, int flags, bool enabled, const QString &text) const { TQ_UNUSED(fm); return static_cast<const TQStyle*>(this)->tqitemRect(NULL, r, flags, enabled, NULL, text); }
@@ -487,7 +487,7 @@ public:
inline static TQRect tqvisualRect( const QRect &logical, const QRect &bounding ) { return visualRect(QApplication::layoutDirection(), bounding, logical); }
// virtual void tqdrawPrimitiveBase( TQ_PrimitiveElement pe, TQPainter *p, const TQRect &r, const TQColorGroup &cg, SFlags flags = Style_Default, const TQStyleOption &opt = TQStyleOption::Default ) const = 0;
- virtual TQSize tqsizeFromContents( ContentsType contents, const TQWidget *widget, const TQSize &contentsSize, const TQStyleOption& = TQStyleOption::Default ) const = 0;
+ virtual TQSize sizeFromContents( ContentsType contents, const TQWidget *widget, const TQSize &contentsSize, const TQStyleOption& = TQStyleOption::Default ) const = 0;
virtual int tqstyleHint( TQ_StyleHint stylehint, const TQWidget *widget = 0, const TQStyleOption& = TQStyleOption::Default, TQStyleHintReturn* returnData = 0) const = 0;
virtual TQRect subRect( SubRect r, const TQWidget *widget ) const = 0; // There doesn't seem to be a Qt4 equivalent for this virtual function; should it just be left as-is here?
virtual TQRect tqitemRect( QPainter *p, const QRect &r, int flags, bool enabled, const QPixmap *pixmap, const QString &text, int len = -1 ) const;
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqt.h b/experimental/tqtinterface/qt4/src/kernel/tqt.h
index 3e1fefa60..e88f88ef3 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqt.h
+++ b/experimental/tqtinterface/qt4/src/kernel/tqt.h
@@ -44,7 +44,7 @@
#include <stdio.h>
#include "tqtextstream.h"
#include "tqfontinfo.h"
-#include "tqsizepolicy.h"
+#include "sizepolicy.h"
#include "tqtl.h"
#include "tqsize.h"
#include "tqrect.h"
@@ -195,7 +195,7 @@
#include <tqsignalslotimp.h>
#include <tqsimplerichtext.h>
#include "tqwmatrix.h"
-#include <tqsizegrip.h>
+#include <sizegrip.h>
#include <tqabstractlayout.h>
#include <tqsjiscodec.h>
#include <tqslider.h>
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqtglobaldefines.h b/experimental/tqtinterface/qt4/src/kernel/tqtglobaldefines.h
index 7fc31682f..35de7c745 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqtglobaldefines.h
+++ b/experimental/tqtinterface/qt4/src/kernel/tqtglobaldefines.h
@@ -195,11 +195,11 @@
// #define tqcrossCursor Qt::CrossCursor
// #define tqwaitCursor Qt::WaitCursor
// #define tqibeamCursor Qt::IBeamCursor
-// #define tqsizeVerCursor Qt::SizeVerCursor
-// #define tqsizeHorCursor Qt::SizeHorCursor
-// #define tqsizeBDiagCursor Qt::SizeBDiagCursor
-// #define tqsizeFDiagCursor Qt::SizeFDiagCursor
-// #define tqsizeAllCursor Qt::SizeAllCursor
+// #define sizeVerCursor Qt::SizeVerCursor
+// #define sizeHorCursor Qt::SizeHorCursor
+// #define sizeBDiagCursor Qt::SizeBDiagCursor
+// #define sizeFDiagCursor Qt::SizeFDiagCursor
+// #define sizeAllCursor Qt::SizeAllCursor
// #define tqblankCursor Qt::BlankCursor
// #define tqsplitVCursor Qt::SplitVCursor
// #define tqsplitHCursor Qt::SplitHCursor
@@ -213,11 +213,11 @@
#define tqcrossCursor TQt::crossCursor
#define tqwaitCursor TQt::waitCursor
#define tqibeamCursor TQt::ibeamCursor
-#define tqsizeVerCursor TQt::sizeVerCursor
-#define tqsizeHorCursor TQt::sizeHorCursor
-#define tqsizeBDiagCursor TQt::sizeBDiagCursor
-#define tqsizeFDiagCursor TQt::sizeFDiagCursor
-#define tqsizeAllCursor TQt::sizeAllCursor
+#define sizeVerCursor TQt::sizeVerCursor
+#define sizeHorCursor TQt::sizeHorCursor
+#define sizeBDiagCursor TQt::sizeBDiagCursor
+#define sizeFDiagCursor TQt::sizeFDiagCursor
+#define sizeAllCursor TQt::sizeAllCursor
#define tqblankCursor TQt::blankCursor
#define tqsplitVCursor TQt::splitVCursor
#define tqsplitHCursor TQt::splitHCursor
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp b/experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp
index bd022e148..e80e19057 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp
+++ b/experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp
@@ -60,7 +60,7 @@
#include "tqbitmap.h"
#include "tqcursor.h"
#include "tqdatetime.h"
-#include "tqsizepolicy.h"
+#include "sizepolicy.h"
#include "tqshared.h"
#include "tqbitarray.h"
#include "tqkeysequence.h"
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp.new b/experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp.new
index 22c05b3c8..3e4141513 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp.new
+++ b/experimental/tqtinterface/qt4/src/kernel/tqvariant.cpp.new
@@ -60,7 +60,7 @@
#include "tqbitmap.h"
#include "tqcursor.h"
#include "tqdatetime.h"
-#include "tqsizepolicy.h"
+#include "sizepolicy.h"
#include "tqshared.h"
#include "tqbitarray.h"
#include "tqkeysequence.h"
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqwidget.cpp b/experimental/tqtinterface/qt4/src/kernel/tqwidget.cpp
index 3bfdd86fd..c9d59d239 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqwidget.cpp
+++ b/experimental/tqtinterface/qt4/src/kernel/tqwidget.cpp
@@ -302,7 +302,7 @@ const TQRect TQWidget::tqgeometry() const {
}
QSize TQWidget::sizeHint() const {
- return tqsizeHint();
+ return sizeHint();
}
QSize TQWidget::minimumSizeHint() const {
@@ -436,7 +436,7 @@ void TQWidget::tqrepaint(const QRegion &rgn, bool) {
repaint(rgn);
}
-TQSizePolicy TQWidget::tqsizePolicy() const {
+TQSizePolicy TQWidget::sizePolicy() const {
return TQT_TQSIZEPOLICY_OBJECT(sizePolicy());
}
@@ -1447,13 +1447,13 @@ TQStyle* TQWidget::setStyle( const TQString &style )
}
/*!
- \property TQWidget::tqsizeHint
+ \property TQWidget::sizeHint
\brief the recommended size for the widget
If the value of this property is an invalid size, no size is
recommended.
- The default implementation of tqsizeHint() returns an invalid size
+ The default implementation of sizeHint() returns an invalid size
if there is no tqlayout for this widget, and returns the tqlayout's
preferred size otherwise.
@@ -1461,7 +1461,7 @@ TQStyle* TQWidget::setStyle( const TQString &style )
setMinimumSize(), updateGeometry()
*/
-TQSize TQWidget::tqsizeHint() const
+TQSize TQWidget::sizeHint() const
{
#ifndef TQT_NO_LAYOUT
if ( tqlayout() )
@@ -2624,11 +2624,11 @@ int TQWidget::x11Depth() const {
/*!
Adjusts the size of the widget to fit the contents.
- Uses tqsizeHint() if valid (i.e if the size hint's width and height
+ Uses sizeHint() if valid (i.e if the size hint's width and height
are \>= 0), otherwise sets the size to the tqchildren rectangle (the
union of all child widget geometries).
- \sa tqsizeHint(), tqchildrenRect()
+ \sa sizeHint(), tqchildrenRect()
*/
void TQWidget::adjustSize()
@@ -2637,7 +2637,7 @@ void TQWidget::adjustSize()
TQApplication::sendPostedEvents( 0, TQEvent::LayoutHint );
if ( !testWState(WState_Polished) )
polish();
- TQSize s = tqsizeHint();
+ TQSize s = sizeHint();
if ( isTopLevel() ) {
@@ -2819,7 +2819,7 @@ WState TQWidget::testWState( TQt::WidgetState s ) const {
height(),
sizePolicy(),
tqsetSizePolicy(),
- tqsizeHint(),
+ sizeHint(),
updateGeometry(),
tqlayout(),
move(),
@@ -3091,11 +3091,11 @@ WState TQWidget::testWState( TQt::WidgetState s ) const {
\i In the constructor, be sure to set up your member variables
early on, before there's any chance that you might receive an event.
- \i It is almost always useful to reimplement tqsizeHint() and to set
+ \i It is almost always useful to reimplement sizeHint() and to set
the correct size policy with tqsetSizePolicy(), so users of your class
can set up tqlayout management more easily. A size policy lets you
supply good defaults for the tqlayout management handling, so that
- other widgets can contain and manage yours easily. tqsizeHint()
+ other widgets can contain and manage yours easily. sizeHint()
indicates a "good" size for the widget.
\i If your widget is a top-level window, setCaption() and setIcon() set
@@ -3205,7 +3205,7 @@ static TQPalette qt_naturalWidgetPalette( TQWidget* w ) {
#endif
TQSize qt_naturalWidgetSize( TQWidget *w ) {
- TQSize s = w->tqsizeHint();
+ TQSize s = w->sizeHint();
TQ_SPExpandData exp;
#ifndef TQT_NO_LAYOUT
if ( w->tqlayout() ) {
@@ -4911,7 +4911,7 @@ void TQWidget::setMaximumHeight( int h )
Sets both the minimum and maximum width of the widget to \a w
without changing the heights. Provided for convenience.
- \sa tqsizeHint() tqminimumSize() tqmaximumSize() setFixedSize()
+ \sa sizeHint() tqminimumSize() tqmaximumSize() setFixedSize()
*/
void TQWidget::setFixedWidth( int w )
@@ -4925,7 +4925,7 @@ void TQWidget::setFixedWidth( int w )
Sets both the minimum and maximum heights of the widget to \a h
without changing the widths. Provided for convenience.
- \sa tqsizeHint() tqminimumSize() tqmaximumSize() setFixedSize()
+ \sa sizeHint() tqminimumSize() tqmaximumSize() setFixedSize()
*/
void TQWidget::setFixedHeight( int h )
@@ -6895,7 +6895,7 @@ void TQWidget::polish()
Ensures that the widget is properly initialized by calling
polish().
- Call constPolish() from functions like tqsizeHint() that depends on
+ Call constPolish() from functions like sizeHint() that depends on
the widget being initialized, and that may be called before
show().
@@ -7134,11 +7134,11 @@ TQRegion TQWidget::clipRegion() const
/*!
Adjusts the size of the widget to fit the contents.
- Uses tqsizeHint() if valid (i.e if the size hint's width and height
+ Uses sizeHint() if valid (i.e if the size hint's width and height
are \>= 0), otherwise sets the size to the tqchildren rectangle (the
union of all child widget geometries).
- \sa tqsizeHint(), tqchildrenRect()
+ \sa sizeHint(), tqchildrenRect()
*/
void TQWidget::adjustSize()
@@ -7147,7 +7147,7 @@ void TQWidget::adjustSize()
TQApplication::sendPostedEvents( 0, TQEvent::LayoutHint );
if ( !testWState(WState_Polished) )
polish();
- TQSize s = tqsizeHint();
+ TQSize s = sizeHint();
if ( isTopLevel() ) {
@@ -7184,13 +7184,13 @@ void TQWidget::adjustSize()
/*!
- \property TQWidget::tqsizeHint
+ \property TQWidget::sizeHint
\brief the recommended size for the widget
If the value of this property is an invalid size, no size is
recommended.
- The default implementation of tqsizeHint() returns an invalid size
+ The default implementation of sizeHint() returns an invalid size
if there is no tqlayout for this widget, and returns the tqlayout's
preferred size otherwise.
@@ -7198,7 +7198,7 @@ void TQWidget::adjustSize()
setMinimumSize(), updateGeometry()
*/
-TQSize TQWidget::tqsizeHint() const
+TQSize TQWidget::sizeHint() const
{
#ifndef TQT_NO_LAYOUT
if ( tqlayout() )
@@ -8455,7 +8455,7 @@ void TQWidget::setLayout( TQLayout *l )
The default policy is Preferred/Preferred, which means that the
widget can be freely resized, but prefers to be the size
- tqsizeHint() returns. Button-like widgets set the size policy to
+ sizeHint() returns. Button-like widgets set the size policy to
specify that they may stretch horizontally, but are fixed
vertically. The same applies to lineedit controls (such as
TQLineEdit, TQSpinBox or an editable TQComboBox) and other
@@ -8466,9 +8466,9 @@ void TQWidget::setLayout( TQLayout *l )
respective direction only. Widgets that can provide scrollbars
(usually subclasses of TQScrollView) tend to specify that they can
use additional space, and that they can make do with less than
- tqsizeHint().
+ sizeHint().
- \sa tqsizeHint() TQLayout TQSizePolicy updateGeometry()
+ \sa sizeHint() TQLayout TQSizePolicy updateGeometry()
*/
TQSizePolicy TQWidget::sizePolicy() const
{
@@ -8580,7 +8580,7 @@ TQWidget *TQWidget::tqchildAt( const TQPoint & p, bool includeThis ) const
Notifies the tqlayout system that this widget has changed and may
need to change tqgeometry.
- Call this function if the tqsizeHint() or sizePolicy() have changed.
+ Call this function if the sizeHint() or sizePolicy() have changed.
For explicitly hidden widgets, updateGeometry() is a no-op. The
tqlayout system will be notified as soon as the widget is shown.
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqwidget.h b/experimental/tqtinterface/qt4/src/kernel/tqwidget.h
index c0274646c..4f0e36b90 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqwidget.h
+++ b/experimental/tqtinterface/qt4/src/kernel/tqwidget.h
@@ -51,7 +51,7 @@
#include "tqfont.h"
#include "tqfontmetrics.h"
#include "tqfontinfo.h"
-#include "tqsizepolicy.h"
+#include "sizepolicy.h"
#include "tqbitmap.h"
#endif // TQT_H
@@ -244,7 +244,7 @@ public:
TQObject *child( const char *objName, const char *inheritsClass = 0, bool recursiveSearch = TRUE );
const TQRect tqgeometry() const;
TQLayout *tqlayout() const;
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
virtual TQSize tqminimumSizeHint() const;
virtual QSize sizeHint() const;
virtual QSize minimumSizeHint() const;
@@ -286,7 +286,7 @@ public:
void tqrepaint(int x, int y, int w, int h, bool);
void tqrepaint(const QRect &r, bool);
void tqrepaint(const QRegion &rgn, bool);
- TQSizePolicy tqsizePolicy() const;
+ TQSizePolicy sizePolicy() const;
TQPoint backgroundOffset() const;
bool tqsignalsBlocked() const;
TQObjectList *queryList( const char *inheritsClass = 0, const char *objName = 0, bool regexpMatch = TRUE, bool recursiveSearch = TRUE ) const;
@@ -638,7 +638,7 @@ class TQ_EXPORT TQWidget : public TQObject, public TQPaintDevice
Q_PROPERTY( bool minimized READ isMinimized )
Q_PROPERTY( bool maximized READ isMaximized )
Q_PROPERTY( bool fullScreen READ isFullScreen )
- Q_PROPERTY( TQSize tqsizeHint READ tqsizeHint )
+ Q_PROPERTY( TQSize sizeHint READ sizeHint )
Q_PROPERTY( TQSize tqminimumSizeHint READ tqminimumSizeHint )
Q_PROPERTY( TQRect microFocusHint READ microFocusHint )
Q_PROPERTY( bool acceptDrops READ acceptDrops WRITE setAcceptDrops )
@@ -900,7 +900,7 @@ public:
uint windowState() const;
void setWindowState(uint windowState);
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
virtual TQSize tqminimumSizeHint() const;
virtual TQSizePolicy sizePolicy() const;
virtual void tqsetSizePolicy( TQSizePolicy );
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqabstractlayout.cpp b/experimental/tqtinterface/qt4/src/kernel/tqabstractlayout.cpp
index 4c15ee267..a40822ccf 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqabstractlayout.cpp
+++ b/experimental/tqtinterface/qt4/src/kernel/tqabstractlayout.cpp
@@ -55,7 +55,7 @@
layouts.
If \a b is TRUE, margin handling needs to be implemented in
- setGeometry(), tqmaximumSize(), tqminimumSize(), tqsizeHint() and
+ setGeometry(), tqmaximumSize(), tqminimumSize(), sizeHint() and
heightForWidth().
\sa supportsMargin()
@@ -100,7 +100,7 @@ static int menuBarHeightForWidth( TQMenuBar *menubar, int w )
This is used by custom layouts.
Pure virtual functions are provided to return information about
- the tqlayout, including, tqsizeHint(), tqminimumSize(), tqmaximumSize()
+ the tqlayout, including, sizeHint(), tqminimumSize(), tqmaximumSize()
and expandingDirections().
The tqlayout's tqgeometry can be set and retrieved with setGeometry()
@@ -173,7 +173,7 @@ static int menuBarHeightForWidth( TQMenuBar *menubar, int w )
*/
/*!
- \fn TQSize TQLayoutItem::tqsizeHint() const
+ \fn TQSize TQLayoutItem::sizeHint() const
Implemented in subclasses to return the preferred size of this item.
*/
@@ -403,7 +403,7 @@ void TQWidgetItem::setGeometry( const TQRect &r )
int x = r.x();
int y = r.y();
if ( align & (TQt::AlignHorizontal_Mask | TQt::AlignVertical_Mask) ) {
- TQSize pref = wid->tqsizeHint().expandedTo( wid->tqminimumSize() ); //###
+ TQSize pref = wid->sizeHint().expandedTo( wid->tqminimumSize() ); //###
if ( align & TQt::AlignHorizontal_Mask )
s.setWidth( TQMIN( s.width(), pref.width() ) );
if ( align & TQt::AlignVertical_Mask ) {
@@ -535,7 +535,7 @@ TQ_SPExpandData TQSpacerItem::expandingDirections() const
/*!
Returns whether this item's widget can make use of more space than
- tqsizeHint(). A value of \c Vertical or \c Horizontal means that it wants
+ sizeHint(). A value of \c Vertical or \c Horizontal means that it wants
to grow in only one dimension, whereas \c BothDirections means that
it wants to grow in both dimensions and \c NoDirection means that
it doesn't want to grow at all.
@@ -657,7 +657,7 @@ TQSize TQWidgetItem::tqmaximumSize() const
/*!
Returns the preferred size of this spacer item.
*/
-TQSize TQSpacerItem::tqsizeHint() const
+TQSize TQSpacerItem::sizeHint() const
{
return QSpacerItem::sizeHint();
}
@@ -668,7 +668,7 @@ TQSize TQSpacerItem::tqsizeHint() const
/*!
Returns the preferred size of this spacer item.
*/
-TQSize TQSpacerItem::tqsizeHint() const
+TQSize TQSpacerItem::sizeHint() const
{
return TQSize( width, height );
}
@@ -678,13 +678,13 @@ TQSize TQSpacerItem::tqsizeHint() const
/*!
Returns the preferred size of this item.
*/
-TQSize TQWidgetItem::tqsizeHint() const
+TQSize TQWidgetItem::sizeHint() const
{
TQSize s;
if ( isEmpty() ) {
s = TQSize( 0, 0 );
} else {
- s = wid->tqsizeHint();
+ s = wid->sizeHint();
if ( TQT_TQSIZEPOLICY_OBJECT(wid->sizePolicy()).horData() == TQSizePolicy::Ignored )
s.setWidth( 1 );
if ( TQT_TQSIZEPOLICY_OBJECT(wid->sizePolicy()).verData() == TQSizePolicy::Ignored )
@@ -732,7 +732,7 @@ bool TQWidgetItem::isEmpty() const
overview page \endlink for more information.
To make your own tqlayout manager, subclass TQGLayoutIterator and
- implement the functions addItem(), tqsizeHint(), setGeometry(), and
+ implement the functions addItem(), sizeHint(), setGeometry(), and
iterator(). You should also implement tqminimumSize() to ensure your
tqlayout isn't resized to zero size if there is too little space. To
support tqchildren whose heights depend on their widths, implement
@@ -1145,7 +1145,7 @@ TQSize TQLayout::totalSizeHint() const
}
int b = ( topLevel && !marginImpl ) ? 2 * outsideBorder : 0;
- TQSize s = tqsizeHint();
+ TQSize s = sizeHint();
if ( hasHeightForWidth() )
s.setHeight( heightForWidth(s.width()) );
int h = b;
@@ -1303,7 +1303,7 @@ TQSize TQLayout::tqmaximumSize() const
/*!
Returns whether this tqlayout can make use of more space than
- tqsizeHint(). A value of \c Vertical or \c Horizontal means that it wants
+ sizeHint(). A value of \c Vertical or \c Horizontal means that it wants
to grow in only one dimension, whereas \c BothDirections means that
it wants to grow in both dimensions.
@@ -1390,7 +1390,7 @@ bool TQLayout::activate()
if (ms.isValid())
mw->setMinimumSize( ms );
// ideally only if tqsizeHint() or sizePolicy() has changed
mw->updateGeometry();
return TRUE;
}
@@ -1421,7 +1421,7 @@ bool TQLayout::activate()
The horizontal and vertical \l{SizeType}s are set in the usual constructor
and can be queried using a variety of functions.
- The hasHeightForWidth() flag indicates whether the widget's tqsizeHint()
+ The hasHeightForWidth() flag indicates whether the widget's sizeHint()
is width-dependent (such as a word-wrapping label) or not.
\sa TQSizePolicy::SizeType
@@ -1433,35 +1433,35 @@ bool TQLayout::activate()
The per-dimension sizing types used when constructing a
TQSizePolicy are:
- \value Fixed The TQWidget::tqsizeHint() is the only acceptable
+ \value Fixed The TQWidget::sizeHint() is the only acceptable
alternative, so the widget can never grow or shrink (e.g. the
vertical direction of a push button).
- \value Minimum The tqsizeHint() is minimal, and sufficient. The
+ \value Minimum The sizeHint() is minimal, and sufficient. The
widget can be expanded, but there is no advantage to it being
larger (e.g. the horizontal direction of a push button).
- It cannot be smaller than the size provided by tqsizeHint().
+ It cannot be smaller than the size provided by sizeHint().
- \value Maximum The tqsizeHint() is a maximum. The widget can be
+ \value Maximum The sizeHint() is a maximum. The widget can be
shrunk any amount without detriment if other widgets need the
space (e.g. a separator line).
- It cannot be larger than the size provided by tqsizeHint().
+ It cannot be larger than the size provided by sizeHint().
- \value Preferred The tqsizeHint() is best, but the widget can be
+ \value Preferred The sizeHint() is best, but the widget can be
shrunk and still be useful. The widget can be expanded, but there
- is no advantage to it being larger than tqsizeHint() (the default
+ is no advantage to it being larger than sizeHint() (the default
TQWidget policy).
- \value Expanding The tqsizeHint() is a sensible size, but the
+ \value Expanding The sizeHint() is a sensible size, but the
widget can be shrunk and still be useful. The widget can make use
of extra space, so it should get as much space as possible (e.g.
the horizontal direction of a slider).
- \value MinimumExpanding The tqsizeHint() is minimal, and sufficient.
+ \value MinimumExpanding The sizeHint() is minimal, and sufficient.
The widget can make use of extra space, so it should get as much
space as possible (e.g. the horizontal direction of a slider).
- \value Ignored the tqsizeHint() is ignored. The widget will get as
+ \value Ignored the sizeHint() is ignored. The widget will get as
much space as possible.
*/
@@ -1475,13 +1475,13 @@ bool TQLayout::activate()
any direction.
\value Horizontally the widget can usefully be wider than the
- tqsizeHint().
+ sizeHint().
\value Vertically the widget can usefully be taller than the
- tqsizeHint().
+ sizeHint().
\value BothDirections the widget can usefully be both wider and
- taller than the tqsizeHint().
+ taller than the sizeHint().
*/
/*!
@@ -1543,7 +1543,7 @@ bool TQLayout::activate()
\fn bool TQSizePolicy::mayShrinkHorizontally() const
Returns TRUE if the widget can sensibly be narrower than its
- tqsizeHint(); otherwise returns FALSE.
+ sizeHint(); otherwise returns FALSE.
\sa mayShrinkVertically() mayGrowHorizontally()
*/
@@ -1552,7 +1552,7 @@ bool TQLayout::activate()
\fn bool TQSizePolicy::mayShrinkVertically() const
Returns TRUE if the widget can sensibly be shorter than its
- tqsizeHint(); otherwise returns FALSE.
+ sizeHint(); otherwise returns FALSE.
\sa mayShrinkHorizontally() mayGrowVertically()
*/
@@ -1561,7 +1561,7 @@ bool TQLayout::activate()
\fn bool TQSizePolicy::mayGrowHorizontally() const
Returns TRUE if the widget can sensibly be wider than its
- tqsizeHint(); otherwise returns FALSE.
+ sizeHint(); otherwise returns FALSE.
\sa mayGrowVertically() mayShrinkHorizontally()
*/
@@ -1570,7 +1570,7 @@ bool TQLayout::activate()
\fn bool TQSizePolicy::mayGrowVertically() const
Returns TRUE if the widget can sensibly be taller than its
- tqsizeHint(); otherwise returns FALSE.
+ sizeHint(); otherwise returns FALSE.
\sa mayGrowHorizontally() mayShrinkVertically()
*/
@@ -1579,7 +1579,7 @@ bool TQLayout::activate()
\fn TQ_SPExpandData TQSizePolicy::expandingDirections() const
Returns whether this tqlayout can make use of more space than
- tqsizeHint(). A value of \c Vertical or \c Horizontal means that it wants
+ sizeHint(). A value of \c Vertical or \c Horizontal means that it wants
to grow in only one dimension, whereas \c BothDirections means that
it wants to grow in both dimensions.
@@ -1847,7 +1847,7 @@ TQGLayoutIterator::~TQGLayoutIterator()
height-for-width (hasHeightForWidth()), this is
the same as \c Minimium; otherwise, this is the
same as \c FreeResize.
- \value Fixed The main widget's size is set to tqsizeHint(); it
+ \value Fixed The main widget's size is set to sizeHint(); it
cannot be resized at all.
\value Minimum The main widget's minimum size is set to
tqminimumSize(); it cannot be smaller.
@@ -1953,7 +1953,7 @@ void TQLayout::setAutoAdd( bool b )
layouts.
If \a b is TRUE, margin handling needs to be implemented in
- setGeometry(), tqmaximumSize(), tqminimumSize(), tqsizeHint() and
+ setGeometry(), tqmaximumSize(), tqminimumSize(), sizeHint() and
heightForWidth().
\sa supportsMargin()
@@ -1968,12 +1968,12 @@ void TQLayout::setSupportsMargin( bool b )
this tqlayout is set to \a r, provided that this tqlayout supports
tqsetAlignment().
- The result is derived from tqsizeHint() and expandingDirections(). It is never
+ The result is derived from sizeHint() and expandingDirections(). It is never
larger than \a r.
*/
TQRect TQLayout::alignmentRect( const TQRect &r ) const
{
- TQSize s = tqsizeHint();
+ TQSize s = sizeHint();
int a = tqalignment();
/*
@@ -1390,7 +1390,7 @@ bool TQLayout::activate()
if (ms.isValid())
mw->setMinimumSize( ms );
- // ideally only if tqsizeHint() or sizePolicy() has changed
+ // ideally only if sizeHint() or sizePolicy() has changed
mw->updateGeometry();
return TRUE;